<?php

class MailtemplateController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
    public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array(''),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('delete'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete','index','view','create','update'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	} 

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Mailtemplate;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Mailtemplate']))
		{
			$model->attributes=$_POST['Mailtemplate'];
            $model->template_body = $_POST['Mailtemplate']['template_body'];
            $model->template_admin_body = $_POST['Mailtemplate']['template_admin_body'];
            if($model->save())
			     $this->redirect(array('/template/mailtemplate'));
            //	$this->redirect(array('view','id'=>$model->template_id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Mailtemplate']))
		{
			$model->attributes=$_POST['Mailtemplate'];
            $model->template_body = $_POST['Mailtemplate']['template_body'];
            $model->template_admin_body = $_POST['Mailtemplate']['template_admin_body'];
			if($model->save())
            {    
                $this->redirect(array('/template/mailtemplate'));
			//	$this->redirect(array('view','id'=>$model->template_id));
            }
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('/template/mailtemplate'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		
        $model = new Mailtemplate('search');
		
        $criteria = new CDbCriteria;
        
        $total = Mailtemplate::model()->count($criteria);   
        
        if(isset($_REQUEST['row'])){
        	$count = $_REQUEST['row'];
        }else {
        	$count = Yii::app()->params['PAGE_LIMIT'];
        }
        
        $pages = new CPagination($total);
        $pages->setPageSize($count);
        $pages->applyLimit($criteria);  
        $posts = Mailtemplate::model()->findAll($criteria);
        
        $this->render('index',array('model'=>$model,'list'=>$posts,'pages' => $pages,'item_count'=>$total,'page_size'=>$count)) ;   
       
        
        /* $dataProvider=new CActiveDataProvider('Mailtemplate');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));*/
	}
 

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Mailtemplate the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Mailtemplate::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Mailtemplate $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='mailtemplate-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}
